@@ -25,7 +25,9 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with(:value => 'false') }
+      it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_nova_config('vnc/novncproxy_base_url') }
       it { is_expected.to contain_nova_config('key_manager/api_class').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>') }
@@ -72,7 +74,9 @@ describe 'nova::compute' do
           :heal_instance_info_cache_interval  => '120',
           :pci_passthrough                    => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
           :config_drive_format                => 'vfat',
+          :resize_confirm_window              => '3',
           :vcpu_pin_set                       => ['4-12','^8','15'],
+          :resume_guests_state_on_host_boot   => true,
           :keymgr_api_class                   => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :barbican_endpoint                  => 'http://localhost',
           :barbican_api_version               => 'v1',
@@ -127,13 +131,18 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with(:value => false) }
 
+      it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('3') }
+
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '4-12,^8,15') }
 
+      it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
+
       it 'configures nova pci_passthrough_whitelist entries' do
         is_expected.to contain_nova_config('DEFAULT/pci_passthrough_whitelist').with(
           'value' => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]"
         )
       end
+
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
         is_expected.to_not contain_package('genisoimage').with(
@@ -143,14 +152,18 @@ describe 'nova::compute' do
     end
 
 
-    context 'when vcpu_pin_set is empty' do
+    context 'when vcpu_pin_set and pci_passthrough are empty' do
       let :params do
-        { :vcpu_pin_set => "" }
+        { :vcpu_pin_set    => "",
+          :pci_passthrough => "" }
       end
 
       it 'clears vcpu_pin_set configuration' do
         is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>')
       end
+      it 'clears pci_passthrough configuration' do
+        is_expected.to contain_nova_config('DEFAULT/pci_passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
+      end
     end
 
     context 'with neutron_enabled set to false' do
@@ -240,6 +253,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit').with_value(true) }
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_value('year') }
     end
+
     context 'with vnc_keymap set to fr' do
       let :params do
         { :vnc_keymap => 'fr', }
